#
# Conditional build:
%bcond_without	igbinary	# memcached igbinary serializer support
%bcond_without	json		# memcached json serializer support
%bcond_without	msgpack		# memcached msgpack serializer support
%bcond_without	sasl		# memcached sasl support
%bcond_without	session		# memcached session handler support
%bcond_without	tests		# build without tests

%define		php_name	php%{?php_suffix}
%define		modname	memcached
Summary:	Interface to memcached via libmemcached library
Summary(pl.UTF-8):	Interfejs do memcached z użyciem biblioteki libmemcached
Name:		%{php_name}-pecl-%{modname}
# for PHP < 7 support see 2.2.x branch
Version:	3.0.0
Release:	1
License:	PHP 3.01
Group:		Development/Languages/PHP
Source0:	https://github.com/php-memcached-dev/php-memcached/archive/php7/%{modname}-%{version}.tar.gz
# Source0-md5:	df81b124ac101bd21922deb0ef2ad9b9
URL:		http://pecl.php.net/package/memcached/
BuildRequires:	%{php_name}-devel >= 4:7.0.0
%{?with_igbinary:BuildRequires:	%{php_name}-pecl-igbinary-devel}
%{?with_msgpack:BuildRequires:	%{php_name}-pecl-msgpack-devel}
%{?with_sasl:BuildRequires:	cyrus-sasl-devel}
BuildRequires:	fastlz-devel
BuildRequires:	libmemcached-devel >= 1.0.18
BuildRequires:	pkgconfig
BuildRequires:	re2c
BuildRequires:	rpmbuild(macros) >= 1.650
BuildRequires:	zlib-devel
%if %{with tests}
BuildRequires:	%{php_name}-cli
BuildRequires:	%{php_name}-pcre
%{?with_igbinary:BuildRequires:	%{php_name}-pecl-igbinary}
%{?with_msgpack:BuildRequires:	%{php_name}-pecl-msgpack}
%{?with_session:BuildRequires:	%{php_name}-session}
BuildRequires:	%{php_name}-spl
%endif
%{?requires_php_extension}
Suggests:	%{php_name}-pecl-igbinary
Suggests:	%{php_name}-pecl-msgpack
Suggests:	%{php_name}-session
Provides:	php(%{modname}) = %{version}
Obsoletes:	php-pecl-memcached < 2.2.0-1
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
This extension uses libmemcached library to provide API for
communicating with memcached servers.

%description -l pl.UTF-8
Rozszerzenie to wykorzystuje bibliotekę memcached w celu udostępnienia
API do komunikacji z serwerami memcached.

%prep
%setup -qc
mv php-memcached-*/{.??*,*} .

rm fastlz/fastlz.c

# redirect tests fail (the actual tests they redirect work)
rm tests/experimental/serializer_igbinary.phpt
rm tests/experimental/serializer_json.phpt

%build
phpize
%configure \
	%{__enable_disable igbinary memcached-igbinary} \
	%{__enable_disable json memcached-json} \
	%{__enable_disable msgpack memcached-msgpack} \
	%{__enable_disable sasl memcached-sasl} \
	%{__enable_disable session memcached-session} \
	--with-system-fastlz
%{__make}

%if %{with tests}
# simple module load test
%{__php} -n -q \
	-d extension_dir=modules \
	-d extension=%{php_extensiondir}/pcre.so \
	-d extension=%{php_extensiondir}/spl.so \
%if %{with session}
	-d extension=%{php_extensiondir}/session.so \
%endif
%if %{with igbinary}
	-d extension=%{php_extensiondir}/igbinary.so \
%endif
%if %{with msgpack}
	-d extension=%{php_extensiondir}/msgpack.so \
%endif
	-d extension=%{modname}.so \
	-m > modules.log
grep %{modname} modules.log

cat <<'EOF' > run-tests.sh
#!/bin/sh
export NO_INTERACTION=1 REPORT_EXIT_STATUS=1 MALLOC_CHECK_=2
exec %{__make} test \
	PHP_EXECUTABLE=%{__php} \
	PHP_TEST_SHARED_SYSTEM_EXTENSIONS="spl%{?with_session: session}%{?with_igbinary: igbinary}%{?with_msgpack: msgpack}" \
	RUN_TESTS_SETTINGS="-q $*"
EOF
chmod +x run-tests.sh

./run-tests.sh
%endif

%install
rm -rf $RPM_BUILD_ROOT
%{__make} install \
	INSTALL_ROOT=$RPM_BUILD_ROOT \
	EXTENSION_DIR=%{php_extensiondir}

install -d $RPM_BUILD_ROOT%{php_sysconfdir}/conf.d
cat <<'EOF' > $RPM_BUILD_ROOT%{php_sysconfdir}/conf.d/%{modname}.ini
; Enable %{modname} extension module
extension=%{modname}.so

EOF
cat %{modname}.ini >> $RPM_BUILD_ROOT%{php_sysconfdir}/conf.d/%{modname}.ini

%clean
rm -rf $RPM_BUILD_ROOT

%post
%php_webserver_restart

%postun
if [ "$1" = 0 ]; then
	%php_webserver_restart
fi

%files
%defattr(644,root,root,755)
%doc CREDITS
%config(noreplace) %verify(not md5 mtime size) %{php_sysconfdir}/conf.d/%{modname}.ini
%attr(755,root,root) %{php_extensiondir}/%{modname}.so
%changelog
* Tue Nov 22 2016 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/php-pecl-memcached.git;a=log;h=master

* Tue Nov 22 2016 Elan Ruusamäe <glen@delfi.ee> ecf7e00
- ah, that i686 spl requires pcre issue again

* Tue Nov 22 2016 Elan Ruusamäe <glen@delfi.ee> bc194a7
- msgpack support; enable it

* Tue Nov 22 2016 Elan Ruusamäe <glen@delfi.ee> 01be7f5
- disable redirect tests; enable igbinary

* Tue Nov 22 2016 Elan Ruusamäe <glen@delfi.ee> 2a973f5
- create run tests wrapper

* Tue Nov 22 2016 Elan Ruusamäe <glen@delfi.ee> cba71c6
- igbinary support

* Tue Nov 22 2016 Elan Ruusamäe <glen@delfi.ee> f320a8b
- run tests

* Tue Nov 22 2016 Elan Ruusamäe <glen@delfi.ee> 8a94fd6
- add bconds for all features

* Tue Nov 22 2016 Elan Ruusamäe <glen@delfi.ee> b39e72b
- update BR

* Tue Nov 22 2016 Elan Ruusamäe <glen@delfi.ee> c3fa9f0
- min php version is 7.0.0

* Tue Nov 22 2016 Elan Ruusamäe <glen@delfi.ee> b791cdb
- use recommended version

* Tue Nov 22 2016 Elan Ruusamäe <glen@delfi.ee> 6668157
- libmemcached-devel dep from package.xml

* Tue Nov 22 2016 Elan Ruusamäe <glen@delfi.ee> 2ef5d14
- use system fastlz

* Tue Nov 22 2016 Elan Ruusamäe <glen@delfi.ee> 32929cc
- up to 3.0.0b1 git snapshot from php7 branch; php7 support

* Fri May 16 2014 Elan Ruusamäe <glen@delfi.ee> d30795a
- obsolete old php name
- release 2 (by relup.sh)

* Tue Apr 29 2014 Elan Ruusamäe <glen@delfi.ee> 87acf0f
- up to 2.2.0

* Sun Nov 24 2013 Elan Ruusamäe <glen@delfi.ee> 28bdaf6
- provide php(extname) to really be supporting multiple php versions

* Mon Oct 07 2013 Elan Ruusamäe <glen@delfi.ee> a08a0b3
- rebuild with libmemcached
- release 3 (by relup.sh)

* Fri Jul 19 2013 Elan Ruusamäe <glen@delfi.ee> 1da063a
- release 2 (by relup.sh)

* Fri Jun 21 2013 Elan Ruusamäe <glen@delfi.ee> 00a979f
- support building for multiple php versions

* Fri Sep 14 2012 Łukasz Kieś <kiesiu@pld-linux.org> 3ad4075
- updated to 2.1.0

